@@ -9,7 +9,7 @@ def get_token(key, secret, auth0_domain=None) -> str:
     domain = auth0_domain or datawhys.auth0_domain
 
     gt = GetToken(domain)
-    resp = gt.client_credentials(key, secret, "https://api.datawhys.ai/")
+    resp = gt.client_credentials(key, secret, "https://api.mondobrain.com/")
     access = resp.get("access_token", None)
 
     return access
